get_ndc_from_name: Get NDC code from medication name

Description Usage Arguments Examples

View source: R/redbook_funcs.R

Description

'get_ndc_from_name' returns the ndc code, or the corresponding redbook entries, for medications of a given name. The name provided is matched to the variables "genme" and "prodnme" in the redbook file.

Usage

1
get_ndc_from_name(term, return_all = FALSE)

Arguments

term

A medication name

Examples

1
2
get_ndc_from_name("omeprazole")
get_ndc_from_name("omeprazole",TRUE)

a1arakkal/icdplus documentation built on Oct. 31, 2019, 1:51 a.m.