Description Usage Arguments Examples
View source: R/redbook_funcs.R
'get_ndc_from_name' returns the ndc code, or the corresponding redbook entries, for medications of a given name. The name provided is matched to the variables "genme" and "prodnme" in the redbook file.
1 | get_ndc_from_name(term, return_all = FALSE)
|
term |
A medication name |
1 2 | get_ndc_from_name("omeprazole")
get_ndc_from_name("omeprazole",TRUE)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.